# -*- coding: utf-8 -*-

from django.db import IntegrityError
from django.db.models import  ObjectDoesNotExist

MTX_TYPE_PM = {
    'structure': 0,
    'agri': 1,
    'bio': 2,
}

def get_type_structure(instance):
    try:
        instance.agriculteur
    except ObjectDoesNotExist:
        return "structure"
    try:
        instance.agriculteur.agriculteurbio
    except ObjectDoesNotExist:
        return "agri"
    return "bio"
    

def update_type_pm(model, dryrun=True, verbose=False, south=False):
    "enumere les structures et met a jour le type dans le nouveau champs"
    qset = model.objects.order_by('designation')
    for elm in qset:
        elm.type_pm = MTX_TYPE_PM.get(get_type_structure(elm), 0)
        if verbose:
            print u"{0} - {1}".format(
                get_type_structure(elm), elm.get_type_pm_display())
        if not dryrun:
            if south:
                elm.save()
            else:
                elm.save(rawsave=True)
            

def check_type_pm(model, verbose=False, south=False):
    "enumere les structures et met a jour le type dans le nouveau champs"
    qset = model.objects.all()
    rep_errors = {
        'count': 0,
        'err_list': [],
        }
    for elm in qset:
        target_type_pm = MTX_TYPE_PM.get(get_type_structure(elm), 0)
        if elm.type_pm != target_type_pm:
            rep_errors['count'] += 1
#            rep_errors['err_list'].append(elm)
            if verbose:
                print u"{0} != {1} ({2})".format(
                    elm.type_pm, target_type_pm, elm)
    if south:
        if rep_errors['count'] > 0:
            raise IntegrityError("{0} errors".format(rep_errors['count']))
    print u"{0}/{1} err/enr.".format(rep_errors['count'], len(qset))

# EOF
