from django.contrib.auth import models as am
from django.core.exceptions import ValidationError
from django.test import TestCase

from contacts import models as cm
from contacts.tests.utils import mfty, cfty
from references import models as rm


class ValDonneesBioView(TestCase):

    def setUp(self):
        self.usr1 = am.User.objects.create_superuser('usr1', '', 'mdp')
        self.usr1.save()
        self.client.login(username = self.usr1.username, password = 'mdp')
        self.fjur = rm.FormeJuridique()
        self.fjur.save()
        self.culture = rm.Culture()
        self.culture.save()
        self.i_pm = {
            'date_creation': '2014-10-01',
            'date_derniere_modification': '2014-10-02',
            'utilisateur_derniere_modification': self.usr1,
            'f_juridique': self.fjur,
            'designation': "test",
            'type_pm': 1,
            }
        self.structure = cfty(cm.Structure, self.i_pm)
        self.data = {
            'agriculteur_bio': self.structure.id,
            'annee': 2013,
            'assolement_set-TOTAL_FORMS': u'0', 
            'assolement_set-INITIAL_FORMS': u'0', 
            'assolement_set-MAX_NUM_FORMS': u'',
            
            'commercialisation_set-TOTAL_FORMS': u'0', 
            'commercialisation_set-INITIAL_FORMS': u'0', 
            'commercialisation_set-MAX_NUM_FORMS': u'', 
            
            'transformation_set-TOTAL_FORMS': u'0', 
            'transformation_set-INITIAL_FORMS': u'0', 
            'transformation_set-MAX_NUM_FORMS': u'', 
            }

    def test_creation(self):
        """La premiere fois que des donnees bio sont entrees il ne doit pas
        y avoir de commercialisation/assolement/transformation
        Lorsque des donnees ont deja ete entrees les annees precedentes il 
        faut reprendre ces informations
        Lorsque des donnees ont deja ete entrees pour l'annee en cours
        il faut reconduire vers ces donnees"""
        
        # En passant par la vue admin d'une structure
        
        # Premiere creation de donnees bio
        response = self.client.get(
            '/private/contacts/structure/'+
            str(self.structure.id)+'/donneesbio/add/',
            follow=True)
        self.check_inline(response, 0, 0, 0)
        path = response.request['PATH_INFO']
        
        # Insertion de donnees
        data = self.data.copy()
        data['lait_nb_vaches'] = u'100'
        data['lait_vaches'] = u'True'
        data['assolement_set-TOTAL_FORMS'] = u'1'
        data['assolement_set-0-culture'] = str(self.culture.id)
        data['assolement_set-0-agriculteur_bio'] = str(self.structure.id)
        response = self.client.post(path, data)
        response = self.client.get(path)
        self.assertEqual(response.context['adminform'].form.initial[
            'lait_nb_vaches'], 100)
        self.check_inline(response, 1, 0, 0)
        
        # Creation d'une autre fiche de donnees qui doit comporter les donnees
        # precedemment entrees
        response = self.client.get(
            '/private/contacts/structure/'+
            str(self.structure.id)+'/donneesbio/add/',
            follow=True)
        self.assertNotEqual(response.request['PATH_INFO'], path)
        self.assertEqual(response.context['adminform'].form.initial[
            'lait_nb_vaches'], 100)
        self.check_inline(response, 1, 0, 0)
        
    def check_inline(self, response, nb_assol, nb_trans, nb_commerc):
        nb_assolement = response.context[
        'inline_admin_formsets'][0].formset.total_form_count()
        nb_transformation = response.context[
        'inline_admin_formsets'][1].formset.total_form_count()
        nb_commercialisation = response.context[
        'inline_admin_formsets'][2].formset.total_form_count()
        self.assertEqual(nb_assolement, nb_assol)
        self.assertEqual(nb_transformation, nb_trans)
        self.assertEqual(nb_commercialisation, nb_commerc)
