# -*- coding: utf-8 -*-
from django.contrib.auth import models as am
from django.core.exceptions import ValidationError
from django.test import TestCase

from contacts import models as cm
from contacts.tests.utils import mfty, cfty
from references import models as rm


class ValPersonne(TestCase):

    def setUp(self):
        self.usr1 = am.User.objects.create_user('usr1')
        self.fjur = rm.FormeJuridique()
        self.fjur.save()
        self.i_pm = {
            'date_creation': '2014-10-01',
            'date_derniere_modification': '2014-10-02',
            'utilisateur_derniere_modification': self.usr1,
            'f_juridique': self.fjur,
            'designation': "test",
            }
        self.i_p = {
            'nom': 'testnom',
            'prenom': 'testprenom',
            }

    def test_personne_dateNaiss(self):
        """Si une personne est rattachee a un agriculteur ou un agriculteur bio il doit
        - avoir une date de naissance"""
        # Une personne rattachee a une structure sans date de naissance sans erreur
        struc = cfty(cm.Structure, self.i_pm, type_pm = 0)
        personne = mfty(cm.Personne, self.i_p, structure = struc)
        personne.full_clean()
        # Une personne rattachee a un agri sans date de naissance avec erreur
        struc.type_pm = 1
        personne.structure = struc
        self.assertRaises(ValidationError, personne.full_clean)
        # Une personne rattachee a un agri avec date de naissance sans erreur
        personne.date_naissance='2000-01-01'
        personne.full_clean()
        
    def test_personne_etiquette(self):
        """L'étiquette sous forme de liste doit contenir le nom_prenom
        avec les & remplacés par &amp, chaque ligne de l'adresse et 
        l'association du code postal et de la ville"""
        # Une personne avec nom, prenom et adresse
        struc = cfty(cm.Structure, self.i_pm, type_pm = 0)
        personne = mfty(cm.Personne, self.i_p, structure = struc)
        personne.nom = "test&nom"
        personne.adresse = "62 rue des \n Cacahuètes"
        etiquette = personne.contenu_etiquette()
        self.assertEqual(etiquette, ["TEST&amp;NOM testprenom", "62 rue des ", 
                                    " Cacahuètes", " "])
        # Une personne avec nom, prenom, adresse, code postal et ville
        personne.ville = "Canarville"
        personne.code_postal = "10000"
        etiquette = personne.contenu_etiquette()
        self.assertEqual(etiquette, ["TEST&amp;NOM testprenom", "62 rue des ", 
                                    " Cacahuètes", "10000 Canarville"])
# EOF
