from django.contrib.auth import models as am
from django.core.exceptions import ValidationError
from django.test import TestCase

from contacts import models as cm
from contacts.tests.utils import mfty, cfty
from references import models as rm


class ValProjetBio(TestCase):

    def setUp(self):
        self.usr1 = am.User.objects.create_user('usr1')
        self.fjur = rm.FormeJuridique()
        self.fjur.save()
        self.i_pm = {
            'date_creation': '2014-10-01',
            'date_derniere_modification': '2014-10-02',
            'utilisateur_derniere_modification': self.usr1,
            'f_juridique': self.fjur,
            'designation': "test",
            }
        self.i_projet = {
            'agriculteur': cfty(cm.Structure, self.i_pm, type_pm = 1)
            }

    def test_frein(self):
        """ Il faut qu'au moins un des points proposes soit un frein """
        # Aucun point propose n'est un frein avec erreur
        projet = mfty(cm.ProjetBio, self.i_projet, installation_bio = True)
        self.assertRaises(ValidationError, projet.full_clean)
        # Au moins un point propose est un frein sans erreur
        projet.pond_commercialisation = -1
        projet.full_clean()

    def test_installation(self):
        """ Il faut preciser si l'installation est bio """
        # Il n'est pas precise si l'installation est bio avec erreur
        projet = mfty(cm.ProjetBio, self.i_projet, pond_commercialisation = -1)
        self.assertRaises(ValidationError, projet.full_clean)
        # Il est precise si l'installation est bio sans erreur
        projet.installation_bio = True
        projet.full_clean()
# EOF
